@@ -36,9 +36,9 @@ int main(int argc, char **argv)
     about.addAuthor(i18n("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org"));
     about.addAuthor(i18n("Albert Vaca Cintora"), QString(), QStringLiteral("albertvaka@gmail.com"));
     QCommandLineParser parser;
-    parser.addOption(QCommandLineOption(QStringList(QStringLiteral("l")) << QStringLiteral("list-devices"), i18n("List all devices")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("l"), QStringLiteral("list-devices")}, i18n("List all devices")));
     parser.addOption(
-        QCommandLineOption(QStringList(QStringLiteral("a")) << QStringLiteral("list-available"), i18n("List available (paired and reachable) devices")));
+        QCommandLineOption(QStringList{QStringLiteral("a"), QStringLiteral("list-available")}, i18n("List available (paired and reachable) devices")));
     parser.addOption(
         QCommandLineOption(QStringLiteral("id-only"), i18n("Make --list-devices or --list-available print only the devices id, to ease scripting")));
     parser.addOption(
@@ -51,6 +51,7 @@ int main(int argc, char **argv)
     parser.addOption(QCommandLineOption(QStringLiteral("unpair"), i18n("Stop pairing to a said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("ping"), i18n("Sends a ping to said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("ping-msg"), i18n("Same as ping but you can set the message to display"), i18n("message")));
+    parser.addOption(QCommandLineOption(QStringLiteral("send-clipboard"), i18n("Sends the current clipboard to said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("share"), i18n("Share a file/URL to a said device"), QStringLiteral("path or URL")));
     parser.addOption(QCommandLineOption(QStringLiteral("share-text"), i18n("Share text to a said device"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringLiteral("list-notifications"), i18n("Display the notifications on a said device")));
@@ -61,15 +62,14 @@ int main(int argc, char **argv)
     parser.addOption(QCommandLineOption(QStringLiteral("attachment"),
                                         i18n("File urls to send attachments with the message (can be passed multiple times)"),
                                         i18n("file urls")));
-    parser.addOption(QCommandLineOption(QStringList(QStringLiteral("device")) << QStringLiteral("d"), i18n("Device ID"), QStringLiteral("dev")));
-    parser.addOption(QCommandLineOption(QStringList(QStringLiteral("name")) << QStringLiteral("n"), i18n("Device Name"), QStringLiteral("name")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("device"), QStringLiteral("d")}, i18n("Device ID"), QStringLiteral("dev")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("name"), QStringLiteral("n")}, i18n("Device Name"), QStringLiteral("name")));
     parser.addOption(QCommandLineOption(QStringLiteral("encryption-info"), i18n("Get encryption info about said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("list-commands"), i18n("Lists remote commands and their ids")));
     parser.addOption(QCommandLineOption(QStringLiteral("execute-command"), i18n("Executes a remote command by id"), QStringLiteral("id")));
     parser.addOption(
         QCommandLineOption(QStringList{QStringLiteral("k"), QStringLiteral("send-keys")}, i18n("Sends keys to a said device"), QStringLiteral("key")));
     parser.addOption(QCommandLineOption(QStringLiteral("my-id"), i18n("Display this device's id and exit")));
-    parser.addOption(QCommandLineOption(QStringLiteral("photo"), i18n("Open the connected device's camera and transfer the photo"), QStringLiteral("path")));
 
     // Hidden because it's an implementation detail
     QCommandLineOption deviceAutocomplete(QStringLiteral("shell-device-autocompletion"));
@@ -83,7 +83,6 @@ int main(int argc, char **argv)
     parser.process(app);
     about.processCommandLine(&parser);
 
-    const QString id = QStringLiteral("kdeconnect-cli-") + QString::number(QCoreApplication::applicationPid());
     DaemonDbusInterface iface;
 
     if (parser.isSet(QStringLiteral("my-id"))) {
@@ -93,7 +92,6 @@ int main(int argc, char **argv)
         if (parser.isSet(QStringLiteral("a"))) {
             available = true;
         } else {
-            blockOnReply(iface.acquireDiscoveryMode(id));
             QThread::sleep(2);
         }
         const QStringList devices = blockOnReply<QStringList>(iface.devices(available, available));
@@ -115,12 +113,12 @@ int main(int argc, char **argv)
                 DeviceDbusInterface deviceIface(id);
                 QString statusInfo;
                 const bool isReachable = deviceIface.isReachable();
-                const bool isTrusted = deviceIface.isTrusted();
-                if (isReachable && isTrusted) {
+                const bool isPaired = deviceIface.isPaired();
+                if (isReachable && isPaired) {
                     statusInfo = i18n("(paired and reachable)");
                 } else if (isReachable) {
                     statusInfo = i18n("(reachable)");
-                } else if (isTrusted) {
+                } else if (isPaired) {
                     statusInfo = i18n("(paired)");
                 }
                 QTextStream(stdout) << "- " << deviceIface.name() << ": " << deviceIface.id() << ' ' << statusInfo << Qt::endl;
@@ -132,15 +130,14 @@ int main(int argc, char **argv)
             QTextStream(stderr) << i18n("No devices found") << Qt::endl;
         }
 
-        blockOnReply(iface.releaseDiscoveryMode(id));
     } else if (parser.isSet(QStringLiteral("shell-device-autocompletion"))) {
         // Outputs a list of reachable devices in zsh autocomplete format, with the name as description
         const QStringList devices = blockOnReply<QStringList>(iface.devices(true, false));
         for (const QString &id : devices) {
             DeviceDbusInterface deviceIface(id);
             QString statusInfo;
-            const bool isTrusted = deviceIface.isTrusted();
-            if (isTrusted) {
+            const bool isPaired = deviceIface.isPaired();
+            if (isPaired) {
                 statusInfo = i18n("(paired)");
             } else {
                 statusInfo = i18n("(unpaired)");
@@ -194,22 +191,24 @@ int main(int argc, char **argv)
         if (parser.isSet(QStringLiteral("share"))) {
             QStringList urls;
 
-            QUrl url = QUrl::fromUserInput(parser.value(QStringLiteral("share")), QDir::currentPath());
-            urls.append(url.toString());
+            QString firstArg = parser.value(QStringLiteral("share"));
+            const auto args = QStringList(firstArg) + parser.positionalArguments();
 
-            // Check for more arguments
-            const auto args = parser.positionalArguments();
             for (const QString &input : args) {
                 QUrl url = QUrl::fromUserInput(input, QDir::currentPath());
+                if (url.isEmpty()) {
+                    qWarning() << "URL not valid:" << input;
+                    continue;
+                }
                 urls.append(url.toString());
             }
 
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                              QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/share"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/share").arg(device),
                                                               QStringLiteral("org.kde.kdeconnect.device.share"),
                                                               QStringLiteral("shareUrls"));
 
-            msg.setArguments(QVariantList() << QVariant(urls));
+            msg.setArguments(QVariantList{QVariant(urls)});
             blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
 
             for (const QString &url : qAsConst(urls)) {
@@ -217,10 +216,10 @@ int main(int argc, char **argv)
             }
         } else if (parser.isSet(QStringLiteral("share-text"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                              QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/share"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/share").arg(device),
                                                               QStringLiteral("org.kde.kdeconnect.device.share"),
                                                               QStringLiteral("shareText"));
-            msg.setArguments(QVariantList() << parser.value(QStringLiteral("share-text")));
+            msg.setArguments(QVariantList{parser.value(QStringLiteral("share-text"))});
             blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
             QTextStream(stdout) << i18n("Shared text: %1", parser.value(QStringLiteral("share-text"))) << Qt::endl;
         } else if (parser.isSet(QStringLiteral("lock")) || parser.isSet(QStringLiteral("unlock"))) {
@@ -239,7 +238,6 @@ int main(int argc, char **argv)
                 // Device doesn't exist, go into discovery mode and wait up to 30 seconds for the device to appear
                 QEventLoop wait;
                 QTextStream(stderr) << i18n("waiting for device...") << Qt::endl;
-                blockOnReply(iface.acquireDiscoveryMode(id));
 
                 QObject::connect(&iface, &DaemonDbusInterface::deviceAdded, &iface, [&](const QString &deviceAddedId) {
                     if (device == deviceAddedId) {
@@ -253,29 +251,34 @@ int main(int argc, char **argv)
 
             if (!dev.isReachable()) {
                 QTextStream(stderr) << i18n("Device not found") << Qt::endl;
-            } else if (blockOnReply<bool>(dev.isTrusted())) {
+            } else if (blockOnReply<bool>(dev.isPaired())) {
                 QTextStream(stderr) << i18n("Already paired") << Qt::endl;
             } else {
                 QTextStream(stderr) << i18n("Pair requested") << Qt::endl;
-                blockOnReply(dev.requestPair());
+                blockOnReply(dev.requestPairing());
             }
-            blockOnReply(iface.releaseDiscoveryMode(id));
         } else if (parser.isSet(QStringLiteral("unpair"))) {
             DeviceDbusInterface dev(device);
-            if (!dev.isTrusted()) {
+            if (!dev.isPaired()) {
                 QTextStream(stderr) << i18n("Already not paired") << Qt::endl;
             } else {
                 QTextStream(stderr) << i18n("Unpaired") << Qt::endl;
                 blockOnReply(dev.unpair());
             }
+        } else if (parser.isSet(QStringLiteral("send-clipboard"))) {
+            QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/clipboard").arg(device),
+                                                              QStringLiteral("org.kde.kdeconnect.device.clipboard"),
+                                                              QStringLiteral("sendClipboard"));
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
         } else if (parser.isSet(QStringLiteral("ping")) || parser.isSet(QStringLiteral("ping-msg"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                              QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/ping"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/ping").arg(device),
                                                               QStringLiteral("org.kde.kdeconnect.device.ping"),
                                                               QStringLiteral("sendPing"));
             if (parser.isSet(QStringLiteral("ping-msg"))) {
                 QString message = parser.value(QStringLiteral("ping-msg"));
-                msg.setArguments(QVariantList() << message);
+                msg.setArguments(QVariantList{message});
             }
             blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
         } else if (parser.isSet(QStringLiteral("send-sms"))) {
@@ -310,26 +313,14 @@ int main(int argc, char **argv)
             }
         } else if (parser.isSet(QStringLiteral("ring"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                              QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/findmyphone"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/findmyphone").arg(device),
                                                               QStringLiteral("org.kde.kdeconnect.device.findmyphone"),
                                                               QStringLiteral("ring"));
             blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
-        } else if (parser.isSet(QStringLiteral("photo"))) {
-            const QString fileName = parser.value(QStringLiteral("photo"));
-            if (!fileName.isEmpty()) {
-                QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                                  QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/photo"),
-                                                                  QStringLiteral("org.kde.kdeconnect.device.photo"),
-                                                                  QStringLiteral("requestPhoto"));
-                msg.setArguments({QUrl::fromLocalFile(fileName).toString()});
-                blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
-            } else {
-                QTextStream(stderr) << i18n("Please specify a filename for the photo") << Qt::endl;
-            }
         } else if (parser.isSet(QStringLiteral("send-keys"))) {
             QString seq = parser.value(QStringLiteral("send-keys"));
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                              QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/remotekeyboard"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/remotekeyboard").arg(device),
                                                               QStringLiteral("org.kde.kdeconnect.device.remotekeyboard"),
                                                               QStringLiteral("sendKeyPress"));
             if (seq.trimmed() == QLatin1String("-")) {
