@@ -39,17 +39,15 @@ SmsPlugin::~SmsPlugin()
     // m_conversationInterface is self-deleting, see ~ConversationsDbusInterface for more information
 }
 
-bool SmsPlugin::receivePacket(const NetworkPacket &np)
+void SmsPlugin::receivePacket(const NetworkPacket &np)
 {
     if (np.type() == PACKET_TYPE_SMS_MESSAGES) {
-        return handleBatchMessages(np);
+        handleBatchMessages(np);
     }
 
     if (np.type() == PACKET_TYPE_SMS_ATTACHMENT_FILE && np.hasPayload()) {
-        return handleSmsAttachmentFile(np);
+        handleSmsAttachmentFile(np);
     }
-
-    return true;
 }
 
 void SmsPlugin::sendSms(const QVariantList &addresses, const QString &textMessage, const QVariantList &attachmentUrls, const qint64 subID)
@@ -123,7 +121,7 @@ void SmsPlugin::forwardToTelepathy(const ConversationMessage &message)
         return;
 
     qCDebug(KDECONNECT_PLUGIN_SMS) << "Passing a text message to the telepathy interface";
-    connect(&m_telepathyInterface, SIGNAL(messageReceived(QString, QString)), SLOT(sendSms(QString, QString)), Qt::UniqueConnection);
+    connect(&m_telepathyInterface, SIGNAL(messageReceived(QString, QString)), this, SLOT(sendSms(QString, QString)), Qt::UniqueConnection);
     const QString messageBody = message.body();
     const QString contactName; // TODO: When telepathy support is improved, look up the contact with KPeople
     const QString phoneNumber = message.addresses()[0].address();
@@ -233,7 +231,7 @@ Attachment SmsPlugin::createAttachmentFromUrl(const QString &url)
 
 QString SmsPlugin::dbusPath() const
 {
-    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/sms");
+    return QLatin1String("/modules/kdeconnect/devices/%1/sms").arg(device()->id());
 }
 
 void SmsPlugin::launchApp()
@@ -241,4 +239,5 @@ void SmsPlugin::launchApp()
     QProcess::startDetached(QLatin1String("kdeconnect-sms"), {QStringLiteral("--device"), device()->id()});
 }
 
+#include "moc_smsplugin.cpp"
 #include "smsplugin.moc"
