@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef VIRTUALMONITORPLUGIN_H
-#define VIRTUALMONITORPLUGIN_H
+#pragma once
 
 #include "plugin_virtualmonitor_debug.h"
 #include <QJsonObject>
@@ -22,14 +21,14 @@ class VirtualMonitorPlugin : public KdeConnectPlugin
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.virtualmonitor")
 
 public:
-    explicit VirtualMonitorPlugin(QObject *parent, const QVariantList &args);
+    using KdeConnectPlugin::KdeConnectPlugin;
     ~VirtualMonitorPlugin() override;
 
     Q_SCRIPTABLE bool requestVirtualMonitor();
 
     void connected() override;
     QString dbusPath() const override;
-    bool receivePacket(const NetworkPacket &np) override;
+    void receivePacket(const NetworkPacket &np) override;
 
 private:
     void stop();
@@ -38,5 +37,3 @@ private:
     QJsonObject m_remoteResolution;
     uint m_retries = 0;
 };
-
-#endif
