@@ -5,22 +5,22 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#include "conversationmodel.h"
 #include "conversationlistmodel.h"
+#include "conversationmodel.h"
 #include "conversationssortfilterproxymodel.h"
-#include "thumbnailsprovider.h"
 #include "kdeconnect-version.h"
+#include "thumbnailsprovider.h"
 
+#include <KAboutData>
+#include <KColorSchemeManager>
+#include <KDBusService>
+#include <KLocalizedContext>
+#include <KLocalizedString>
 #include <QApplication>
-#include <QQmlApplicationEngine>
 #include <QCommandLineParser>
+#include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QQuickStyle>
-#include <KAboutData>
-#include <KLocalizedString>
-#include <KLocalizedContext>
-#include <KDBusService>
-#include <KColorSchemeManager>
 
 #include "smshelper.h"
 
@@ -45,16 +45,18 @@ int main(int argc, char *argv[])
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("kdeconnect-sms");
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
     KAboutData aboutData(QStringLiteral("kdeconnect.sms"),
                          i18n("KDE Connect SMS"),
                          QStringLiteral(KDECONNECT_VERSION_STRING),
                          i18n("SMS Instant Messaging"),
                          KAboutLicense::GPL_V3,
-                         i18n("(C) 2018-2019, KDE Connect Team"));
+                         i18n("(C) 2018-2022, KDE Connect Team"));
     aboutData.addAuthor(i18n("Simon Redman"), {}, QStringLiteral("simon@ergotech.com"));
     aboutData.addAuthor(i18n("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
     aboutData.addAuthor(i18n("Nicolas Fella"), {}, QStringLiteral("nicolas.fella@gmx.de"));
+    aboutData.setBugAddress(QStringLiteral("https://bugs.kde.org/enter_bug.cgi?product=kdeconnect&component=messaging-application").toUtf8());
     KAboutData::setApplicationData(aboutData);
 
 #ifdef Q_OS_WIN
@@ -81,7 +83,7 @@ int main(int argc, char *argv[])
 
     KDBusService service(KDBusService::Unique);
 
-    QObject::connect(&service, &KDBusService::activateRequested, &service, [&parser, &data](const QStringList &args, const QString &/*workDir*/) {
+    QObject::connect(&service, &KDBusService::activateRequested, &service, [&parser, &data](const QStringList &args, const QString & /*workDir*/) {
         parser.parse(args);
 
         data.m_initialMessage = parser.value(QStringLiteral("message"));
@@ -97,14 +99,15 @@ int main(int argc, char *argv[])
 
     qmlRegisterSingletonType<SmsHelper>("org.kde.kdeconnect.sms", 1, 0, "SmsHelper", SmsHelper::singletonProvider);
 
-    qmlRegisterSingletonInstance<AppData>("org.kde.kdeconnect.sms", 1,0, "AppData", &data);
+    qmlRegisterSingletonInstance<AppData>("org.kde.kdeconnect.sms", 1, 0, "AppData", &data);
+
+    qmlRegisterSingletonType("org.kde.kdeconnect.sms", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+        return engine->toScriptValue(KAboutData::applicationData());
+    });
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.addImageProvider(QStringLiteral("thumbnailsProvider"), new ThumbnailsProvider);
-    engine.rootContext()->setContextProperties({
-        { QStringLiteral("aboutData"), QVariant::fromValue(KAboutData::applicationData()) }
-    });
     engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
     return app.exec();
